@@ -44,5 +44,5 @@ main = do
                 <> progDesc "Run a static StatusNotifierItem"
                 )
   buildItem itemParams
-  void getChar
+  void $ getChar
 
